#!/usr/bin/python
# -*- coding: UTF-8 -*-

from datetime import datetime
from decimal import Decimal

import base64
import json


class Row(object):
    def __init__(self, schema, columns):
        """

        :param list schema:
        :param list columns:
        """
        self._schema = schema
        self._row = Row._get_row(schema, columns)

    @staticmethod
    def _get_row(schema, columns):
        tmp_row = []
        for idx in range(len(columns)):
            tmp_row.append(Row._get_column(schema[idx].type, columns[idx]))

        return tmp_row

    @staticmethod
    def _get_column(type_string, value_string):
        if (value_string == '\x08\uFEFF' or value_string == '\xa0\x08\ufeff' or
                value_string == '\x08' or value_string is None):
            return None

        if type_string == 'boolean':
            if value_string == 'False' or value_string is False:
                return False
            return True
        elif (type_string == 'tinyint' or type_string == 'smallint' or type_string == 'short' or type_string == 'int'
              or type_string == 'bigint' or type_string == 'long' or type_string == 'byte'):
            return int(value_string)
        elif type_string == 'float' or type_string == 'double' or type_string == 'real':
            return float(value_string)
        elif type_string.startswith('decimal'):
            return Decimal(value_string)
        elif type_string.startswith('timestamp') or type_string == 'time':
            tm = int(value_string)
            tm /= 1000
            try:
                return datetime.fromtimestamp(tm).strftime('%Y-%m-%d %H:%M:%S.%f')
            except OSError:
                return None
        elif type_string == 'binary' or type_string == 'varbinary':
            return base64.b64decode(value_string)
        elif type_string.startswith('array') or type_string.startswith('map') or type_string.startswith(
                'struct') or type_string.startswith('row'):
            if isinstance(value_string, str):
                return json.loads(value_string)
            else:
                return value_string
        else:
            return value_string

    @property
    def columns(self):
        return self._row

    def to_str(self):
        return str(self.columns)

    def __repr__(self):
        return self.to_str()
