#!/usr/bin/python
# -*- coding: UTF-8 -*-

from pprint import pformat


class TableSchema(object):

    def __init__(self, tbl_name, columns, sort_columns=None):
        """
        Init the TableSchema instance

        :param str tbl_name: Table name
        :param list columns: The list of the columns
        :param list sort_columns: The list of the columns for sort
        """

        self._tbl_name = tbl_name
        self._columns = columns
        self._sort_columns = None

        if sort_columns is not None:
            assert isinstance(sort_columns, list)
            self._sort_columns = sort_columns

    @property
    def table_name(self):
        return self._tbl_name

    @property
    def columns(self):
        return self._columns

    @property
    def sort_columns(self):
        return self._sort_columns

    def to_dict(self):
        result = {
            'table_name': self._tbl_name,
            'columns': self._columns,
            'sort_columns': self._sort_columns
        }
        return result

    def to_str(self):
        return pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()


class Table(object):

    def __init__(self, tbl_name, db_name, columns=None, create_time=None, data_type=None, last_access_time=None,
                 location=None, owner=None, table_size=None, table_type=None, description=None):
        self.tbl_name = tbl_name
        self.db_name = db_name
        self._columns = columns
        self._create_time = create_time
        self._data_type = data_type
        self._last_access_time = last_access_time
        self._location = location
        self._owner = owner
        self._table_size = table_size
        self._table_type = table_type
        self._description = description

    @property
    def columns(self):
        return self._columns

    @columns.setter
    def columns(self, columns):
        self._columns = columns

    def partition_columns(self):
        return [x for x in self._columns if x.is_partition_column]

    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        self._create_time = create_time

    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        self._data_type = data_type

    @property
    def last_access_time(self):
        return self._last_access_time

    @last_access_time.setter
    def last_access_time(self, last_access_time):
        self._last_access_time = last_access_time

    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, location):
        self._location = location

    @property
    def owner(self):
        return self._owner

    @owner.setter
    def owner(self, owner):
        self._owner = owner

    @property
    def table_size(self):
        return self._table_size

    @table_size.setter
    def table_size(self, table_size):
        self._table_size = table_size

    @property
    def table_type(self):
        return self._table_type

    @table_type.setter
    def table_type(self, table_type):
        self._table_type = table_type

    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, description):
        self._description = description
